@@ -32,6 +32,8 @@
 #include <dirent.h>
 #include <X11/Xatom.h>
 
+#include <gtk/gtkwindow.h>
+
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkevents.h>
@@ -551,12 +553,6 @@ out:
   if (class_hint.res_name)
     XFree(class_hint.res_name);
 
-  if (app) 
-  {
-    if (!hd_wm_application_is_dummy (app))	  
-      g_signal_emit_by_name (hdwm, "application-starting", app);
-  }
-
   return app;
 }
 
@@ -2224,7 +2220,7 @@ hd_wm_reset_focus (HDWM *hdwm)
   {
     hd_wm_debug ("Making TN unfocusable");
     hdwm->priv->has_focus = FALSE;
-    hd_wm_debug ("%s: %d, hn_window_set_focus (tasknav,FALSE);",__FILE__,__LINE__);
+    hd_wm_set_window_focus (GTK_WIDGET (hdwm->priv->all_menu)->window, FALSE);
   }
 }
 
