@@ -35,6 +35,15 @@ enum
   PROP_MODEL = 1
 };
 
+/* Signals */
+enum
+{
+  ITEM_SELECTED,
+  N_SIGNALS
+};
+
+static guint SIGNALS[N_SIGNALS] = {0};
+
 static GObject *
 hd_app_menu_tree_constructor (GType                   type,
                               guint                   n_construct_params,
@@ -55,6 +64,9 @@ hd_app_menu_tree_get_property (GObject         *object,
 static void
 hd_app_menu_tree_navigation_changed (HDAppMenuTree *tree);
 
+static void
+hd_app_menu_tree_content_changed (HDAppMenuTree *tree);
+
 static void
 hd_app_menu_tree_content_drag_received (HDAppMenuTree  *tree,
                                         GdkDragContext         *context,
@@ -69,6 +81,25 @@ hd_app_menu_tree_navigation_drag_received (HDAppMenuTree          *tree,
                                            gint                    y,
                                            GtkSelectionData       *data);
 
+static gboolean
+hd_app_menu_tree_content_drag_motion (HDAppMenuTree          *tree,
+                                      GdkDragContext         *context,
+                                      gint                    x,
+                                      gint                    y,
+                                      guint                   time);
+
+static gboolean
+hd_app_menu_tree_navigation_drag_motion (HDAppMenuTree          *tree,
+                                         GdkDragContext         *context,
+                                         gint                    x,
+                                         gint                    y,
+                                         guint                   time);
+
+static void
+hd_app_menu_tree_drag_begin (HDAppMenuTree     *tree,
+                             GdkDragContext    *context,
+                             GtkWidget         *widget);
+
 struct _HDAppMenuTreePrivate
 {
   GtkTreeModel         *model, *navigation_model, *content_model;
@@ -115,6 +146,19 @@ hd_app_menu_tree_class_init (HDAppMenuTreeClass *klass)
                                    PROP_MODEL,
                                    pspec);
 
+  SIGNALS[ITEM_SELECTED] = g_signal_new ("item-selected",
+                                         G_OBJECT_CLASS_TYPE (object_class),
+                                         G_SIGNAL_RUN_LAST,
+                                         G_STRUCT_OFFSET (HDAppMenuTreeClass,
+                                                          item_selected),
+                                         NULL,
+                                         NULL,
+                                         g_cclosure_marshal_VOID__OBJECT,
+                                         G_TYPE_NONE,
+                                         1,
+                                         GTK_TYPE_TREE_ITER);
+
+
   g_type_class_add_private (klass, sizeof (HDAppMenuTreePrivate));
 }
 
@@ -126,6 +170,7 @@ hd_app_menu_tree_constructor (GType                   type,
   HDAppMenuTreePrivate *priv;
   GObject              *object;
   GtkTreeViewColumn    *column;
+  GtkWidget            *scrolled_window;
   GtkCellRenderer      *renderer;
   const GtkTargetEntry  target_entries =
   {"HD_APP_MENU_ITEM", GTK_TARGET_SAME_APP, 0x42124212};
@@ -163,7 +208,7 @@ hd_app_menu_tree_constructor (GType                   type,
   gtk_tree_view_column_add_attribute (column,
                                       renderer,
                                       "text",
-                                      TREE_MODEL_NAME);
+                                      TREE_MODEL_LOCALIZED_NAME);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (priv->navigation_pane),
                                column);
@@ -179,10 +224,17 @@ hd_app_menu_tree_constructor (GType                   type,
                                         1,
                                         GDK_ACTION_MOVE);
 
+  g_signal_connect_swapped (priv->navigation_pane, "drag-motion",
+                            G_CALLBACK (hd_app_menu_tree_navigation_drag_motion),
+                            object);
   g_signal_connect_swapped (priv->navigation_pane, "drag-data-received",
                             G_CALLBACK (hd_app_menu_tree_navigation_drag_received),
                             object);
 
+  g_signal_connect_swapped (priv->navigation_pane, "drag-begin",
+                            G_CALLBACK (hd_app_menu_tree_drag_begin),
+                            object);
+
   g_signal_connect_swapped (priv->navigation_pane, "cursor-changed",
                             G_CALLBACK (hd_app_menu_tree_navigation_changed),
                             object);
@@ -190,7 +242,14 @@ hd_app_menu_tree_constructor (GType                   type,
   priv->navigation_selection =
       gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->navigation_pane));
 
-  gtk_paned_add1 (GTK_PANED (object), priv->navigation_pane);
+  scrolled_window = g_object_new (GTK_TYPE_SCROLLED_WINDOW,
+                                  "visible", TRUE,
+                                  "hscrollbar-policy", GTK_POLICY_AUTOMATIC,
+                                  "vscrollbar-policy", GTK_POLICY_AUTOMATIC,
+                                  "child", priv->navigation_pane,
+                                  NULL);
+
+  gtk_paned_add1 (GTK_PANED (object), scrolled_window);
 
   priv->content_pane = g_object_new (GTK_TYPE_TREE_VIEW,
                                      "visible", TRUE,
@@ -215,7 +274,7 @@ hd_app_menu_tree_constructor (GType                   type,
   gtk_tree_view_column_add_attribute (column,
                                       renderer,
                                       "text",
-                                      TREE_MODEL_NAME);
+                                      TREE_MODEL_LOCALIZED_NAME);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (priv->content_pane),
                                column);
@@ -234,10 +293,29 @@ hd_app_menu_tree_constructor (GType                   type,
                             G_CALLBACK (hd_app_menu_tree_content_drag_received),
                             object);
 
+  g_signal_connect_swapped (priv->content_pane, "drag-motion",
+                            G_CALLBACK (hd_app_menu_tree_content_drag_motion),
+                            object);
+
+  g_signal_connect_swapped (priv->content_pane, "drag-begin",
+                            G_CALLBACK (hd_app_menu_tree_drag_begin),
+                            object);
+
+  g_signal_connect_swapped (priv->content_pane, "cursor-changed",
+                            G_CALLBACK (hd_app_menu_tree_content_changed),
+                            object);
+
   priv->content_selection =
       gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->content_pane));
 
-  gtk_paned_add2 (GTK_PANED (object), priv->empty_label);
+  scrolled_window = g_object_new (GTK_TYPE_SCROLLED_WINDOW,
+                                  "visible", TRUE,
+                                  "hscrollbar-policy", GTK_POLICY_AUTOMATIC,
+                                  "vscrollbar-policy", GTK_POLICY_AUTOMATIC,
+                                  "child", priv->content_pane,
+                                  NULL);
+
+  gtk_paned_add2 (GTK_PANED (object), scrolled_window);
 
   return object;
 
@@ -317,6 +395,43 @@ hd_app_menu_tree_navigation_visible (GtkTreeModel      *model,
   return (depth == 1);
 }
 
+static void
+hd_app_menu_tree_content_changed (HDAppMenuTree *tree)
+{
+  HDAppMenuTreePrivate *priv;
+  GtkTreeIter           iter;
+  GtkTreePath          *cursor_path, *main_path;
+
+  priv = tree->priv;
+
+  gtk_tree_view_get_cursor (GTK_TREE_VIEW (priv->content_pane),
+                            &cursor_path,
+                            NULL);
+
+  if (!cursor_path)
+  {
+    g_signal_emit (tree, SIGNALS[ITEM_SELECTED], 0, NULL);
+    return;
+  }
+
+  main_path =
+      gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (priv->content_model),
+                                                        cursor_path);
+
+  if (!main_path)
+  {
+    gtk_tree_path_free (cursor_path);
+    return;
+  }
+
+  if (gtk_tree_model_get_iter (priv->model, &iter, main_path))
+    g_signal_emit (tree, SIGNALS[ITEM_SELECTED], 0, &iter);
+
+  gtk_tree_path_free (cursor_path);
+  gtk_tree_path_free (main_path);
+  return;
+}
+
 static void
 hd_app_menu_tree_navigation_changed (HDAppMenuTree *tree)
 {
@@ -343,6 +458,9 @@ hd_app_menu_tree_navigation_changed (HDAppMenuTree *tree)
   gtk_tree_view_set_model (GTK_TREE_VIEW (priv->content_pane),
                            priv->content_model);
 
+  /* Content was unselected */
+  g_signal_emit (tree, SIGNALS[ITEM_SELECTED], 0, NULL);
+
   if (gtk_tree_model_get_iter_first (priv->content_model, &iter))
   {
     if (priv->content_pane->parent != GTK_WIDGET (tree))
@@ -362,6 +480,51 @@ hd_app_menu_tree_navigation_changed (HDAppMenuTree *tree)
 
 }
 
+static void
+hd_app_menu_tree_drag_begin (HDAppMenuTree     *tree,
+                             GdkDragContext    *context,
+                             GtkWidget         *widget)
+{
+  HDAppMenuTreePrivate *priv = tree->priv;
+  GtkTreeIter           iter;
+  GdkPixbuf            *icon = NULL;
+
+  GTK_WIDGET_GET_CLASS (widget)->drag_begin (widget, context);
+
+  if (widget == priv->content_pane)
+  {
+    if (!gtk_tree_selection_get_selected (priv->content_selection,
+                                          NULL,
+                                          &iter))
+      return;
+
+    gtk_tree_model_get (priv->content_model, &iter,
+                        TREE_MODEL_ICON, &icon,
+                        -1);
+  }
+  else if (widget == priv->navigation_pane)
+  {
+    if (!gtk_tree_selection_get_selected (priv->navigation_selection,
+                                          NULL,
+                                          &iter))
+      return;
+
+    gtk_tree_model_get (priv->navigation_model, &iter,
+                        TREE_MODEL_ICON, &icon,
+                        -1);
+  }
+
+  if (icon)
+  {
+    gtk_drag_set_icon_pixbuf (context, icon, 0, 0);
+    g_object_unref (icon);
+  }
+
+  /* Stop the emission or gtk will use the default icon */
+  g_signal_stop_emission_by_name (widget, "drag-begin");
+
+}
+
 static void
 hd_app_menu_tree_content_drag_received (HDAppMenuTree          *tree,
                                         GdkDragContext         *context,
@@ -545,6 +708,145 @@ hd_app_menu_tree_navigation_drag_received (HDAppMenuTree          *tree,
   }
 }
 
+static gboolean
+hd_app_menu_tree_content_drag_motion (HDAppMenuTree          *tree,
+                                      GdkDragContext         *context,
+                                      gint                    x,
+                                      gint                    y,
+                                      guint                   time)
+{
+  HDAppMenuTreePrivate *priv = tree->priv;
+  GtkWidget            *drag_source;
+
+  drag_source = gtk_drag_get_source_widget (context);
+
+
+  if (drag_source == priv->content_pane)
+  {
+    GtkTreeViewDropPosition     pos;
+    GtkTreePath                *path;
+
+    GTK_WIDGET_CLASS (GTK_TREE_VIEW_GET_CLASS (priv->content_pane))->
+        drag_motion (priv->content_pane,
+                     context,
+                     x, y,
+                     time);
+
+    gtk_tree_view_get_drag_dest_row (GTK_TREE_VIEW (priv->content_pane),
+                                     &path,
+                                     &pos);
+
+    if (path)
+    {
+      if (pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->content_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_BEFORE);
+
+      }
+      else if (pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->content_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_AFTER);
+      }
+
+      gtk_tree_path_free( path );
+    }
+  }
+
+  else if (drag_source == priv->navigation_pane)
+  {
+    gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->content_pane),
+                                     NULL,
+                                     0);
+    gdk_drag_status( context, 0, time );
+  }
+
+  return TRUE;
+}
+static gboolean
+hd_app_menu_tree_navigation_drag_motion (HDAppMenuTree          *tree,
+                                         GdkDragContext         *context,
+                                         gint                    x,
+                                         gint                    y,
+                                         guint                   time)
+{
+  HDAppMenuTreePrivate *priv = tree->priv;
+  GtkWidget            *drag_source;
+  gboolean              valid_location;
+
+  drag_source = gtk_drag_get_source_widget (context);
+
+  valid_location =
+      GTK_WIDGET_CLASS (GTK_TREE_VIEW_GET_CLASS (priv->navigation_pane))->
+                        drag_motion (priv->navigation_pane,
+                                     context,
+                                     x, y,
+                                     time);
+
+  if (drag_source == priv->content_pane)
+  {
+    GtkTreeViewDropPosition     pos;
+    GtkTreePath                *path;
+
+    gtk_tree_view_get_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                     &path,
+                                     &pos);
+
+    if (path)
+    {
+      if (pos == GTK_TREE_VIEW_DROP_BEFORE)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
+
+      }
+      else if (pos == GTK_TREE_VIEW_DROP_AFTER)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
+      }
+
+      gtk_tree_path_free( path );
+    }
+  }
+
+  else if (drag_source == priv->navigation_pane)
+  {
+    GtkTreeViewDropPosition     pos;
+    GtkTreePath                *path;
+
+    gtk_tree_view_get_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                     &path,
+                                     &pos);
+
+    if (path)
+    {
+      if (pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_BEFORE);
+
+      }
+      else if (pos == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
+      {
+        gtk_tree_view_set_drag_dest_row (GTK_TREE_VIEW (priv->navigation_pane),
+                                         path,
+                                         GTK_TREE_VIEW_DROP_AFTER);
+      }
+
+      gtk_tree_path_free( path );
+    }
+  }
+
+  return valid_location;
+}
+
 void
 hd_app_menu_tree_set_model (HDAppMenuTree *tree, GtkTreeModel *model)
 {
@@ -612,15 +914,12 @@ hd_app_menu_tree_get_selected_category (HDAppMenuTree *tree, GtkTreeIter *iter)
   if (!GTK_IS_TREE_MODEL (priv->model))
     return FALSE;
 
-  g_debug ("Running get_selected");
-
   gtk_tree_view_get_cursor (GTK_TREE_VIEW (priv->navigation_pane),
                             &cursor_path,
                             NULL);
 
   if (!cursor_path)
   {
-    g_debug ("No currently selected cat");
     return FALSE;
   }
 
@@ -630,16 +929,12 @@ hd_app_menu_tree_get_selected_category (HDAppMenuTree *tree, GtkTreeIter *iter)
 
   gtk_tree_path_free (cursor_path);
   if (!main_path)
-  {
-    g_debug ("Could not translate path");
     return FALSE;
-  }
 
   result = gtk_tree_model_get_iter (priv->model, iter, main_path);
 
 
   gtk_tree_path_free (main_path);
-  g_debug ("Returning: %i", result);
 
   return result;
 }
