@@ -274,10 +274,13 @@ hd_applications_menu_key_press (GtkWidget *menu,
     }
     else
     {
-      GdkWindow *window = gtk_widget_get_parent_window (button->priv->button);
-     
+      GtkWidget *window = gtk_widget_get_toplevel (button->priv->button);
+      
       gtk_widget_grab_focus (GTK_WIDGET (button->priv->button));
-      hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS, window);
+      
+      g_object_set (window, "can-focus", TRUE, NULL);
+      
+      hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS, window->window);
     }
     
     return TRUE;
@@ -784,6 +787,49 @@ hd_applications_menu_populate (HDApplicationsMenu *button)
   g_list_free (menu_items);
 }
 
+static gboolean 
+hd_applications_menu_categories_motion_notify (GtkWidget      *widget,
+					       GdkEventMotion *event,
+					       HDApplicationsMenu *button)
+{
+  HildonDesktopPopupMenu *menu = HILDON_DESKTOP_POPUP_MENU (widget);
+  GList *menu_items = NULL, *l;
+  gint w,h,x,y;
+
+  gtk_widget_get_pointer (GTK_WIDGET (widget), &x, &y);
+
+  w = widget->allocation.width;
+  h = widget->allocation.height;
+
+  if (!((x >= 0) && (x <= w) && (y >= 0) && (y <= h)))
+    return TRUE;    	 
+
+  menu_items = 
+    hildon_desktop_popup_menu_get_children (menu);
+
+  for (l = menu_items; l != NULL; l = g_list_next (l))
+    gtk_item_deselect (GTK_ITEM (l->data));	  
+
+  for (l = menu_items; l != NULL; l = g_list_next (l))
+  {
+    gtk_widget_get_pointer (GTK_WIDGET (l->data), &x, &y);
+
+    w = GTK_WIDGET (l->data)->allocation.width;
+    h = GTK_WIDGET (l->data)->allocation.height;
+
+    if ((x >= 0) && (x <= w) && (y >= 0) && (y <= h))
+    {	    
+      hildon_desktop_popup_menu_select_item (menu, GTK_MENU_ITEM (l->data));
+      button->priv->focus_applications = TRUE;
+      gtk_menu_item_activate (GTK_MENU_ITEM (l->data));
+    }
+  }
+
+  g_list_free (menu_items);
+
+  return TRUE;
+}
+
 static void
 hd_applications_menu_create_menu (HDApplicationsMenu *button)
 {
@@ -821,6 +867,11 @@ hd_applications_menu_create_menu (HDApplicationsMenu *button)
 		  		    	     "resize-parent", FALSE,
 				    	     NULL));
 
+  g_signal_connect (G_OBJECT (button->priv->menu_categories),
+		    "motion-notify-event",
+		    G_CALLBACK (hd_applications_menu_categories_motion_notify),
+		    button);
+  
   gtk_widget_show (GTK_WIDGET (button->priv->menu_categories));
 
   gtk_widget_set_name (GTK_WIDGET (button->priv->menu_categories), 
@@ -1190,10 +1241,11 @@ hd_applications_menu_register_monitors (HDApplicationsMenu * button)
   g_free (dir);
       
   g_free (conf_file);
-  
+
   /* Monitor the .desktop directories, so we can regenerate the menu
    * when a new application is installed */
-  if (gnome_vfs_monitor_add (&button->priv->desktop_dir_monitor, 
+  if (g_file_test (HD_DESKTOP_ENTRY_PATH, G_FILE_TEST_EXISTS) &&
+      gnome_vfs_monitor_add (&button->priv->desktop_dir_monitor, 
                              HD_DESKTOP_ENTRY_PATH,
                              GNOME_VFS_MONITOR_DIRECTORY,
                              (GnomeVFSMonitorCallback) hd_applications_menu_dir_changed,
@@ -1205,8 +1257,10 @@ hd_applications_menu_register_monitors (HDApplicationsMenu * button)
   }
 
   /* Monitor the hildon .desktop directories, so we can regenerate the 
-   * menu when a new application is installed */
-  if (gnome_vfs_monitor_add (&button->priv->desktop_dir_monitor, 
+   * menu when a new application is installed. Do this only if the default
+   * directory is the standard one ($datadir/applications) */
+  if (g_file_test (HD_DESKTOP_ENTRY_PATH "/hildon", G_FILE_TEST_EXISTS) &&
+      gnome_vfs_monitor_add (&button->priv->desktop_dir_monitor, 
                              HD_DESKTOP_ENTRY_PATH "/hildon",
                              GNOME_VFS_MONITOR_DIRECTORY,
                              (GnomeVFSMonitorCallback) hd_applications_menu_dir_changed,
